.. _all-salt.thorium:

====================================
Full list of builtin thorium modules
====================================

.. currentmodule:: salt.thorium

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    check
    file
    local
    reg
    timer
